@@ -12,8 +12,14 @@ dzil clean &&
 dzil build || exit $?
 dzil cover --outputdir ../cover_db
 
-sleep 1
+sleep 2
 
+cd "${FOLDER}"
+perl Makefile.PL
+cd -
 cp "${FOLDER}/cpanfile" ./
 cp "${FOLDER}/Makefile.PL" ./
+cp "${FOLDER}/MYMETA.yml" ./
+cp "${FOLDER}/MYMETA.json" ./
+
 pod2markdown lib/DBIx/Squirrel.pod >docs/POD/README.md
