@@ -13,10 +13,9 @@ for PREREQ in $(
     cat MYMETA.json |
     jq -r '.prereqs.test.requires, .prereqs.runtime.requires | keys []' | 
     grep -v -E '^perl|lib|open|strict|warnings|List::Util$'
-); do
+)
+do
     cpanm $PREREQ || cpanm --force $PREREQ
 done
-perl Makefile.PL &&
-make &&
-make test
+perl Makefile.PL && make && make test
 cd -
