@@ -12,10 +12,17 @@ dzil clean &&
     dzil build || exit $?
 dzil cover --outputdir ../cover_db
 
-sleep 1
+sleep 2
 
+cd "${FOLDER}"
+perl Makefile.PL
+cd -
 cp "${FOLDER}/cpanfile" ./
 cp "${FOLDER}/Makefile.PL" ./
+cp "${FOLDER}/MYMETA.yml" ./
+cp "${FOLDER}/MYMETA.json" ./
+
+pod2markdown lib/DBIx/Squirrel.pod >docs/POD/README.md
 
 if [ $DEVELOPER_RELEASE -eq 1 ]; then
     dzil release --trial
